#ifndef ST7789_H
#define ST7789_H

#include <stdint.h>

#define ST7789_WIDTH        240U
#define ST7789_HEIGHT       240U
#define ST7789_COLOR_RED    0xF800U
#define ST7789_COLOR_BLUE   0x001FU
#define ST7789_COLOR_WHITE  0xFFFFU

void ST7789_Initialize(void);
void ST7789_FillRect(uint16_t x, uint16_t y, uint16_t width, uint16_t height, uint16_t color);
void ST7789_DrawImageRGB565(uint16_t x, uint16_t y, uint16_t width, uint16_t height, const uint16_t *image);
void ST7789_DrawString8x8(uint16_t x, uint16_t y, const char *text, uint16_t color, uint16_t backgroundColor, uint8_t scale);

#endif /* ST7789_H */